#
# spec file for package mergiraf
#
# Copyright (c) 2025 SUSE LLC
# Copyright (c) 2024, Martin Hauke <mardnh@gmx.de>
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           mergiraf
Version:        0.5.1
Release:        1.1
Summary:        A syntax-aware git merge driver
License:        GPL-3.0-or-later
Group:          Development/Tools/Version Control
URL:            https://mergiraf.org/
#Git-Clone:     https://codeberg.org/mergiraf/mergiraf.git
Source:         %{name}-%{version}.tar.gz
Source1:        vendor.tar.zst
BuildRequires:  cargo-packaging
BuildRequires:  git-core
ExclusiveArch:  %{rust_tier1_arches}

%description
Mergiraf can solve a wide range of Git merge conflicts.
That's because it's aware of the trees in your files!

Thanks to its understanding of your language, it can often
reconcile the needs of both sides.

%prep
%autosetup -a 1

%build
%{cargo_build}

%install
%{cargo_install}

%check
%{cargo_test}

%files
%license LICENSE.txt
%doc README.md
%{_bindir}/mergiraf
%{_bindir}/mgf_dev

%changelog
* Sat Feb  8 2025 Martin Hauke <mardnh@gmx.de>
- Update to version 0.5.1:
  Bugfix release
  * The --compact option works again, without needing to supply
    "--compact=true".
* Thu Feb  6 2025 Martin Hauke <mardnh@gmx.de>
- Update to version 0.5.0:
  New languages
  * PHP
  * Solidity
  * TSX
  * Lua
  * Kotlin
  * Devicetree
  * Ruby
  Improvements
  * The histogram diff algorithm is used for line-based merges.
  * The mgf_dev parse command correctly displays nodes that have
    a signature and are commutative at the same time.
  * Don't add a newline at the end of merged / to-be-merged files.
  * Also parse correctly conflicts with non-newline-terminated
    sides.
  * The --keep-output option was added to the mergiraf solve to
    control the creation of .orig files.
  * The conflict size marker size can be controlled with option -l
  * The commutativity of various syntactic elements was restricted
    to avoid bad merges.
  * A --timeout option is available in mergiraf merge, to fall
    back on line-based merging if structured merging takes too
    long.
  * A panic when failing to commutatively merge a root node was
    fixed.
  Compatibility
  * Support for the MERGIRAF_DISABLE environment variable was
    removed, use mergiraf=0 instead.
  Performance
  * Many improvements reducing memory allocations.
* Sun Dec  8 2024 Martin Hauke <mardnh@gmx.de>
- Update to version 0.4.0:
  New languages
  * Python
  * TOML
  * Scala
  * Typescript
  Performance
  * Many performance improvements.
  Bug fixes
  * The solve command preserves revision names in conflicts.
  * Don't swallow trailing whitespace of merged nodes.
  * Make helpers runnable from any directory.
  New features
  * Replace MERGIRAF_DISABLE=1 by mergiraf=0
  * Support for restricting commutativity.
* Wed Nov 13 2024 mardnh@gmx.de
- Update to version 0.3.1:
  * Updated tree-sitter-xml to 0.7.0
* Tue Nov 12 2024 Martin Hauke <mardnh@gmx.de>
- Update to version 0.3.0
  * New language: Dart (*.dart).
  * .cc files are correctly detected as C++.
  * Documentation improvements.
  * Fixes to the integration test suite when GPG signing is enabled
* Sun Nov 10 2024 Martin Hauke <mardnh@gmx.de>
- Initial package, version 0.2.0
